@@ -1204,6 +1204,6 @@ Mautic.initDismiss();";
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/CoreBundle/Assets/js/1.core.js", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Assets/js/1.core.js");
+        return new Source("", "@bundles/CoreBundle/Assets/js/1.core.js", "/var/www/html/production-demo/app/bundles/CoreBundle/Assets/js/1.core.js");
     }
 }
