@@ -679,6 +679,6 @@ class IntegrationHelper
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/PluginBundle/Helper/IntegrationHelper.php", "/var/www/html/mauticGIT-Test/app/bundles/PluginBundle/Helper/IntegrationHelper.php");
+        return new Source("", "@bundles/PluginBundle/Helper/IntegrationHelper.php", "/var/www/html/production-demo/app/bundles/PluginBundle/Helper/IntegrationHelper.php");
     }
 }
