@@ -227,6 +227,6 @@ class __TwigTemplate_21012fa525eb36beacc4f1a41c372496 extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticCore/Menu/admin.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Resources/views/Menu/admin.html.twig");
+        return new Source("", "@MauticCore/Menu/admin.html.twig", "/var/www/html/production-demo/app/bundles/CoreBundle/Resources/views/Menu/admin.html.twig");
     }
 }
