@@ -2284,6 +2284,6 @@ mQuery(function() {
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/CoreBundle/Assets/js/4.builder.js", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Assets/js/4.builder.js");
+        return new Source("", "@bundles/CoreBundle/Assets/js/4.builder.js", "/var/www/html/production-demo/app/bundles/CoreBundle/Assets/js/4.builder.js");
     }
 }
