@@ -438,6 +438,6 @@ class AssetGenerationHelper
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/CoreBundle/Helper/AssetGenerationHelper.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Helper/AssetGenerationHelper.php");
+        return new Source("", "@bundles/CoreBundle/Helper/AssetGenerationHelper.php", "/var/www/html/production-demo/app/bundles/CoreBundle/Helper/AssetGenerationHelper.php");
     }
 }
