@@ -207,6 +207,6 @@ $context["variant"], "variants" =>                         // line 67
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticCore/Variant/index.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Resources/views/Variant/index.html.twig");
+        return new Source("", "@MauticCore/Variant/index.html.twig", "/var/www/html/production-demo/app/bundles/CoreBundle/Resources/views/Variant/index.html.twig");
     }
 }
