@@ -277,6 +277,6 @@ mautic.config.peak_interaction_timer.fetch_limit.tooltip='Set the maximum number
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/CampaignBundle/Translations/en_US/messages.ini", "/var/www/html/mauticGIT-Test/app/bundles/CampaignBundle/Translations/en_US/messages.ini");
+        return new Source("", "@bundles/CampaignBundle/Translations/en_US/messages.ini", "/var/www/html/production-demo/app/bundles/CampaignBundle/Translations/en_US/messages.ini");
     }
 }
