@@ -312,6 +312,6 @@ $context["e"], "trace", [], "any", false, false, false, 101)]);
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticCore/Exception/base.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Resources/views/Exception/base.html.twig");
+        return new Source("", "@MauticCore/Exception/base.html.twig", "/var/www/html/production-demo/app/bundles/CoreBundle/Resources/views/Exception/base.html.twig");
     }
 }
