@@ -728,6 +728,6 @@ class __TwigTemplate_76a55fe8b633449ae0345a373abad41f extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/cause-buzz/html/email.html.twig", "/var/www/html/mauticGIT-Test/themes/cause-buzz/html/email.html.twig");
+        return new Source("", "@themes/cause-buzz/html/email.html.twig", "/var/www/html/production-demo/themes/cause-buzz/html/email.html.twig");
     }
 }
