@@ -330,6 +330,6 @@ class __TwigTemplate_d4bb34bfa09c1d6274fa8112a1849e41 extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticPage/Page/_list.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/PageBundle/Resources/views/Page/_list.html.twig");
+        return new Source("", "@MauticPage/Page/_list.html.twig", "/var/www/html/production-demo/app/bundles/PageBundle/Resources/views/Page/_list.html.twig");
     }
 }
