@@ -731,6 +731,6 @@ class ThemeHelper implements ThemeHelperInterface
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/CoreBundle/Helper/ThemeHelper.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Helper/ThemeHelper.php");
+        return new Source("", "@bundles/CoreBundle/Helper/ThemeHelper.php", "/var/www/html/production-demo/app/bundles/CoreBundle/Helper/ThemeHelper.php");
     }
 }
