@@ -592,6 +592,6 @@ class ConfigType extends AbstractType
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/EmailBundle/Form/Type/ConfigType.php", "/var/www/html/mauticGIT-Test/app/bundles/EmailBundle/Form/Type/ConfigType.php");
+        return new Source("", "@bundles/EmailBundle/Form/Type/ConfigType.php", "/var/www/html/production-demo/app/bundles/EmailBundle/Form/Type/ConfigType.php");
     }
 }
