@@ -1345,6 +1345,6 @@ body .facetwp-btn {
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/fresh-wide/css/style.css", "/var/www/html/mauticGIT-Test/themes/fresh-wide/css/style.css");
+        return new Source("", "@themes/fresh-wide/css/style.css", "/var/www/html/production-demo/themes/fresh-wide/css/style.css");
     }
 }
