@@ -1510,6 +1510,6 @@ return [
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/CoreBundle/Config/config.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Config/config.php");
+        return new Source("", "@bundles/CoreBundle/Config/config.php", "/var/www/html/production-demo/app/bundles/CoreBundle/Config/config.php");
     }
 }
