@@ -262,6 +262,6 @@ $context["item"], "templateButtons" => ["edit" => CoreExtension::getAttribute($t
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticPoint/Trigger/_list.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/PointBundle/Resources/views/Trigger/_list.html.twig");
+        return new Source("", "@MauticPoint/Trigger/_list.html.twig", "/var/www/html/production-demo/app/bundles/PointBundle/Resources/views/Trigger/_list.html.twig");
     }
 }
