@@ -836,6 +836,6 @@ Mautic.loadEmailUsages = function(\$el) {
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/EmailBundle/Assets/js/email.js", "/var/www/html/mauticGIT-Test/app/bundles/EmailBundle/Assets/js/email.js");
+        return new Source("", "@bundles/EmailBundle/Assets/js/email.js", "/var/www/html/production-demo/app/bundles/EmailBundle/Assets/js/email.js");
     }
 }
