@@ -255,6 +255,6 @@ class __TwigTemplate_25ef544dbabd89ec7ce6a1b2e5c3c8d5 extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticEmail/Send/progress.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/EmailBundle/Resources/views/Send/progress.html.twig");
+        return new Source("", "@MauticEmail/Send/progress.html.twig", "/var/www/html/production-demo/app/bundles/EmailBundle/Resources/views/Send/progress.html.twig");
     }
 }
