@@ -1787,6 +1787,6 @@ class EmailController extends FormController
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/EmailBundle/Controller/EmailController.php", "/var/www/html/mauticGIT-Test/app/bundles/EmailBundle/Controller/EmailController.php");
+        return new Source("", "@bundles/EmailBundle/Controller/EmailController.php", "/var/www/html/production-demo/app/bundles/EmailBundle/Controller/EmailController.php");
     }
 }
