@@ -816,6 +816,6 @@ class SmsController extends FormController
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/SmsBundle/Controller/SmsController.php", "/var/www/html/mauticGIT-Test/app/bundles/SmsBundle/Controller/SmsController.php");
+        return new Source("", "@bundles/SmsBundle/Controller/SmsController.php", "/var/www/html/production-demo/app/bundles/SmsBundle/Controller/SmsController.php");
     }
 }
