@@ -860,6 +860,6 @@ class __TwigTemplate_0fd24e9057cc7de210ddf6abe76aab1d extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@themes/causebuzz-grapejs-suite/html/page.html.twig", "/var/www/html/mauticGIT-Test/themes/causebuzz-grapejs-suite/html/page.html.twig");
+        return new Source("", "@themes/causebuzz-grapejs-suite/html/page.html.twig", "/var/www/html/production-demo/themes/causebuzz-grapejs-suite/html/page.html.twig");
     }
 }
