@@ -273,6 +273,6 @@ $context["values"], "removed", [], "array", true, true, false, 33) &&  !Twig\Ext
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticLead/Auditlog/_table.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/LeadBundle/Resources/views/Auditlog/_table.html.twig");
+        return new Source("", "@MauticLead/Auditlog/_table.html.twig", "/var/www/html/production-demo/app/bundles/LeadBundle/Resources/views/Auditlog/_table.html.twig");
     }
 }
