@@ -613,6 +613,6 @@ class HitRepository extends CommonRepository
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/PageBundle/Entity/HitRepository.php", "/var/www/html/mauticGIT-Test/app/bundles/PageBundle/Entity/HitRepository.php");
+        return new Source("", "@bundles/PageBundle/Entity/HitRepository.php", "/var/www/html/production-demo/app/bundles/PageBundle/Entity/HitRepository.php");
     }
 }
