@@ -358,6 +358,6 @@ class __TwigTemplate_7d70ad0bcb50bc8e854611967f294b78 extends Template
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@MauticAsset/Asset/details.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/AssetBundle/Resources/views/Asset/details.html.twig");
+        return new Source("", "@MauticAsset/Asset/details.html.twig", "/var/www/html/production-demo/app/bundles/AssetBundle/Resources/views/Asset/details.html.twig");
     }
 }
