@@ -302,6 +302,6 @@ mautic.page.result.header.index=\"Results for %name%\"
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/PageBundle/Translations/en_US/messages.ini", "/var/www/html/mauticGIT-Test/app/bundles/PageBundle/Translations/en_US/messages.ini");
+        return new Source("", "@bundles/PageBundle/Translations/en_US/messages.ini", "/var/www/html/production-demo/app/bundles/PageBundle/Translations/en_US/messages.ini");
     }
 }
