@@ -649,6 +649,6 @@ namespace {
 
     public function getSourceContext(): Source
     {
-        return new Source("", "@bundles/CoreBundle/ErrorHandler/ErrorHandler.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/ErrorHandler/ErrorHandler.php");
+        return new Source("", "@bundles/CoreBundle/ErrorHandler/ErrorHandler.php", "/var/www/html/production-demo/app/bundles/CoreBundle/ErrorHandler/ErrorHandler.php");
     }
 }
